@@ -23,6 +23,7 @@ from typing import (
     TypeVar, Union, cast,
 )
 
+import flaky
 import pytest
 
 from coverage import env
@@ -399,6 +400,10 @@ class DebugControlString(DebugControl):
         return self.io.getvalue()
 
 
-def without_color(text: str) -> str:
-    """Remove ANSI color-setting escape sequences."""
-    return re.sub(r"\033\[[\d;]+m", "", text)
+TestMethod = Callable[[Any], None]
+
+def flaky_method(max_runs: int) -> Callable[[TestMethod], TestMethod]:
+    """flaky.flaky, but with type annotations."""
+    def _decorator(fn: TestMethod) -> TestMethod:
+        return cast(TestMethod, flaky.flaky(max_runs)(fn))
+    return _decorator
