@@ -21,13 +21,12 @@ import pytest
 
 from coverage.data import CoverageData, combine_parallel_data
 from coverage.data import add_data_to_hash, line_counts
-from coverage.debug import DebugControlString
 from coverage.exceptions import DataError, NoDataError
 from coverage.files import PathAliases, canonical_filename
 from coverage.types import FilePathClasses, FilePathType, TArc, TLineNo
 
 from tests.coveragetest import CoverageTest
-from tests.helpers import assert_count_equal
+from tests.helpers import DebugControlString, assert_count_equal
 
 
 LINES_1 = {
@@ -82,7 +81,7 @@ def DebugCoverageData(*args: Any, **kwargs: Any) -> CoverageData:
     if kwargs:
         # There's no logical reason kwargs should imply sqldata debugging.
         # This is just a way to get a mix of debug options across the tests.
-        options.append("sqldata")
+        options.extend(["dataop2", "sqldata"])
     debug = DebugControlString(options=options)
     return CoverageData(*args, debug=debug, **kwargs)   # type: ignore[misc]
 
@@ -887,6 +886,9 @@ class CoverageDataFilesTest(CoverageTest):
         covdata1.add_lines(LINES_1)
         covdata1.write()
 
+        # Journal files should never be included in the combining.
+        self.make_file("cov1/.coverage.1-journal", "xyzzy")
+
         os.makedirs('cov2')
         covdata2 = DebugCoverageData('cov2/.coverage.2')
         covdata2.add_lines(LINES_2)
