@@ -15,7 +15,7 @@ from xml.etree import ElementTree
 import pytest
 
 import coverage
-from coverage import Coverage
+from coverage import Coverage, env
 from coverage.exceptions import NoDataError
 from coverage.files import abs_file
 from coverage.misc import import_local_file
@@ -235,11 +235,12 @@ class XmlReportTest(XmlTestHelpers, CoverageTest):
         # https://github.com/nedbat/coveragepy/issues/439
         self.make_file("src/main/foo.py", "a = 1")
         self.make_file("also/over/there/bar.py", "b = 2")
+
         cov = coverage.Coverage(source=["src/main", "also/over/there", "not/really"])
-        cov.start()
-        mod_foo = import_local_file("foo", "src/main/foo.py")                   # pragma: nested
-        mod_bar = import_local_file("bar", "also/over/there/bar.py")            # pragma: nested
-        cov.stop()                                                              # pragma: nested
+        with cov.collect():
+            mod_foo = import_local_file("foo", "src/main/foo.py")
+            mod_bar = import_local_file("bar", "also/over/there/bar.py")
+
         with pytest.warns(Warning) as warns:
             cov.xml_report([mod_foo, mod_bar])
         assert_coverage_warnings(
@@ -320,7 +321,7 @@ class XmlReportTest(XmlTestHelpers, CoverageTest):
 
     def test_no_duplicate_packages(self) -> None:
         self.make_file(
-            "namespace/package/__init__.py", 
+            "namespace/package/__init__.py",
             "from . import sample; from . import test; from .subpackage import test"
         )
         self.make_file("namespace/package/sample.py", "print('package.sample')")
@@ -330,10 +331,8 @@ class XmlReportTest(XmlTestHelpers, CoverageTest):
         # no source path passed to coverage!
         # problem occurs when they are dynamically generated during xml report
         cov = coverage.Coverage()
-
-        cov.start()
-        import_local_file("foo", "namespace/package/__init__.py")               # pragma: nested
-        cov.stop()                                                              # pragma: nested
+        with cov.collect():
+            import_local_file("foo", "namespace/package/__init__.py")
 
         cov.xml_report()
 
@@ -351,6 +350,20 @@ class XmlReportTest(XmlTestHelpers, CoverageTest):
         named_sub_package = dom.findall(".//package[@name='namespace.package.subpackage']")
         assert len(named_sub_package) == 1
 
+    def test_bug_1709(self) -> None:
+        # https://github.com/nedbat/coveragepy/issues/1709
+        self.make_file("main.py", "import x1y, x01y, x001y")
+        self.make_file("x1y.py", "print('x1y')")
+        self.make_file("x01y.py", "print('x01y')")
+        self.make_file("x001y.py", "print('x001y')")
+
+        cov = coverage.Coverage()
+        self.start_import_stop(cov, "main")
+        assert self.stdout() == "x1y\nx01y\nx001y\n"
+        # This used to raise:
+        # TypeError: '<' not supported between instances of 'Element' and 'Element'
+        cov.xml_report()
+
 
 def unbackslash(v: Any) -> Any:
     """Find strings in `v`, and replace backslashes with slashes throughout."""
@@ -476,15 +489,16 @@ class XmlPackageStructureTest(XmlTestHelpers, CoverageTest):
         dom = ElementTree.parse("coverage.xml")
         self.assert_source(dom, "src")
 
-    def test_relative_source(self) -> None:
+    @pytest.mark.parametrize("trail", ["", "/", "\\"])
+    def test_relative_source(self, trail: str) -> None:
+        if trail == "\\" and not env.WINDOWS:
+            pytest.skip("trailing backslash is only for Windows")
         self.make_file("src/mod.py", "print(17)")
-        cov = coverage.Coverage(source=["src"])
+        cov = coverage.Coverage(source=[f"src{trail}"])
         cov.set_option("run:relative_files", True)
         self.start_import_stop(cov, "mod", modfile="src/mod.py")
         cov.xml_report()
 
-        with open("coverage.xml") as x:
-            print(x.read())
         dom = ElementTree.parse("coverage.xml")
         elts = dom.findall(".//sources/source")
         assert [elt.text for elt in elts] == ["src"]
